/*
 * MainActivity.java 
 * A sample main activity
 * Companion code for Chapter 22
 * Android in Action, 3rd Edition
 * C. Enrique Ortiz | http://www.CEnriqueOrtiz
 * May 2011
 */

package com.cenriqueortiz.androidinaction.ch22;

import com.cenriqueortiz.androidinaction.R;
import android.app.ActionBar;
import android.app.ActionBar.OnNavigationListener;
import android.app.Activity;
import android.app.FragmentTransaction;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Toast;

public class MainActivity extends Activity implements ActionBar.TabListener {
	
	// Sample labels for the tabs or list navigation
	private String[] mCategories = new String[] {
			"Technology", 
			"Sports", 
			"Arts"};

	private View mActionBarView;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        // Get the action bar and populate it w/ categories
        //	Check first that the theme an action bar and thus tabs
        ActionBar bar = getActionBar();
        if (bar != null) {

    		// Nav modes:
        	//  NAVIGATION_MODE_LIST --> List navigation mode.
        	//  NAVIGATION_MODE_STANDARD --> Standard navigation mode.
        	//  NAVIGATION_MODE_TABS --> Tab navigation mode.
        	// Set the mode for list navigation
	        bar.setNavigationMode(ActionBar.NAVIGATION_MODE_TABS);

	        // Add each individual tab
	        for (int i=0; i<mCategories.length; i++) {
	            bar.addTab(bar.newTab().setText(mCategories[i]).setTabListener(this));
	        }
        	
    		// Display options:
	        // 	ActionBar.DISPLAY_HOME_AS_UP 
    		// 	ActionBar.DISPLAY_SHOW_CUSTOM 
	        // 	ActionBar.DISPLAY_USE_LOGO
	        // 	ActionBar.DISPLAY_SHOW_HOME
	        // 	ActionBar.DISPLAY_SHOW_TITLE
	        // Set the display options for home icon
	        bar.setDisplayOptions(
	        		ActionBar.DISPLAY_HOME_AS_UP | 
	        		ActionBar.DISPLAY_SHOW_HOME);

	        // Remove the activity title to maximize space for tabs
	        bar.setDisplayShowTitleEnabled(true);

	        // Uncomment for action bar custom view layout
	        //mActionBarView = getLayoutInflater().inflate(R.layout.action_bar_custom, null);
	        //bar.setCustomView(mActionBarView);
	        	        
	        // The adapter for the list navigation 
	        //	(if list nav active as defined by the nav mode)
	        ArrayAdapter<String> navListAdapter = new ArrayAdapter<String>(
	        		this, 
	        		R.layout.spinner_textview, 
	        		mCategories);

	        // The list nav item listener
	        //	(if list nav active as defined by the nav mode)
	        bar.setListNavigationCallbacks(navListAdapter, 
	        	new OnNavigationListener() {
		        	@Override
		        	public boolean onNavigationItemSelected(int position, long itemId) {
		        		// Here dispatch the appropriate Fragment for the selected position
		            	Toast.makeText(MainActivity.this, 
		            			"onNavigationItemSelected: " + position, 
		            			Toast.LENGTH_LONG).show();    	
		        		return true;
		        	}
	        	});
        }
    }

    ////////////////////////////////////////////////////////////////////////////////
    // Tabs
    ////////////////////////////////////////////////////////////////////////////////
    
	/** Is called when a tab is selected */
    public void onTabSelected(ActionBar.Tab tab, FragmentTransaction ft) {
    	// Here load the fragment of interest
    	SummaryListFragment frag = (SummaryListFragment) 
        	getFragmentManager().findFragmentById(R.id.frag_summary_listview);
    	// Notify the list view fragment about the selected tab (position)
    	frag.setCategory(tab.getPosition());
    }

	/** Is called when a tab is unselected */ 
    public void onTabUnselected(ActionBar.Tab tab, FragmentTransaction ft) {
    	//	here add cleanup code or resource management when 
    	//	the tab is unselected
    }

	/** Is called when a tab is re-selected */ 
    public void onTabReselected(ActionBar.Tab tab, FragmentTransaction ft) {
    	//	here add logic to reallocate necessary resources or 
    	//	refresh the tab/fragment.
    }    

    ////////////////////////////////////////////////////////////////////////////////
    // Menus(action items and overflow menu)
    ////////////////////////////////////////////////////////////////////////////////

    @Override
    /** Called when time to create the menu */
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.main_menu, menu);
        return true;
    }

    @Override
    /** Called when menu item has been selected */
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
	        case android.R.id.home:
	        	// The user pressed the home up
	        	 // app icon in Action Bar clicked; go home
	        	Toast.makeText(this, "anroid.R.id.home pressed", Toast.LENGTH_LONG).show();
	            Intent intent = new Intent(this, MainActivity.class);
	            intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
	            startActivity(intent);
	            return true;
	        case R.id.shareitem:
	        	// Handle the share item
	        	Toast.makeText(this, "R.id.shareitem", Toast.LENGTH_LONG).show();
	        	return true;
	        case R.id.menuitem1:
	        	// Handle the menu menu
	        	return true;
	        case R.id.menuitem2:
	        	// Handle the menu menu
	        	return true;
	        case R.id.menuitem3:
	        	// Handle the menu menu
	        	return true;
	        case R.id.menuitem4:
	        	// Handle the menu menu
	        	return true;
            default:
	            return super.onOptionsItemSelected(item);
        }
    }
}
